;This file is copyright (c) 1991, 1992 Informant Communications Group and the
;article author. The material here may be used in an application provided
;that this copyright/disclaimer information is kept in the original source
;file. The material presented here is provided "as is" and with no guarantee.
;Informant Communications Group/Paradox Informant assume no responsibility
;for the use or misuse of the material contained within.
;
;Contents        : procedure FullScreenMenu
;Source File     : FULLMENU.SC
;Author          : Michael Ax
;                  Ax Systems
;                  151 Centre Ave. #4D
;                  New Rochelle, NY  10005
;
;Informant Issue : November 1991
;
;Description     : This routine creates "full screen" menus. It employs
;                  ring style menus like Paradox, but will display all
;                  menu options and descriptions on the center of the screen.
;
; Paradox Informant
; 8525 Elk Grove Blvd.
; Suite 126
; Elk Grove, CA  95624-1777
; Phone: (916) 686-6610
; Fax  : (916) 686-8497
; BBS  : (916) 686-4740

CREATELIB "FullMenu"
;
; FullScreenMenu() uses the SHOWARRAY command to
; define a ring-style menu from the List parameter
; and opens a window listing all menu items and
; their descriptions; color attribute and starting
; row for the window are also passed as parameters
;
PROC FullScreenMenu(Color,Line,List)
  PRIVATE NumItems,ItemNum,MaxLen,MaxItemLen,TempLen,
          TempString,ItemAr,DescripAr,Element,Show

  NumItems=0
  ItemNum =0
  MaxLen  =0
  MaxItemLen=0
  Show=True
  ;
  ; check parameter list
  ;
  IF List=""
    THEN RETURN ""
  ENDIF
  IF Line<3
    THEN Line=3
  ENDIF
  ;
  ; if List begins with a "/" the full (window) menu
  ; is not displayed; Show is reset to False
  ;
  IF MATCH(List,"/..",List)
    THEN Show=False
  ENDIF
  ;
  ; insure that List ends with "~"
  ;
  IF NOT MATCH(List,"..~")
    THEN List=List+"~"
  ENDIF
  ;
  ; count the number of menu items and get length
  ; of longest
  ;
  TempString=List
  WHILE MATCH(TempString,"..~..",Element,TempString)
    TempLen=LEN(Element)
    IF TempLen>MaxLen
      THEN MaxLen=TempLen
    ENDIF
    NumItems=NumItems+1
  ENDWHILE
  MaxLen =MaxLen+6
  ;
  ; populate array elements with menu item names
  ; and descriptions
  ;
  ARRAY ItemAr[NumItems]
  ARRAY DescripAr[NumItems]
  TempString=List
  WHILE MATCH(TempString,"..~..",Element,TempString)
    ItemNum=ItemNum+1
    IF MATCH(Element,"..:..",MenuItem,MenuDescrip)
      THEN ItemAr[ItemNum]=MenuItem
           DescripAr[ItemNum]=MenuDescrip
    ENDIF
    TempLen=LEN(MenuItem)
    IF TempLen>MaxItemLen
      THEN MaxItemLen=TempLen
    ENDIF
  ENDWHILE
  MaxItemLen=MaxItemLen+2
  ;
  ; if Show is True, then display FullMenu window
  ;
  IF Show
    THEN CANVAS OFF
         CLEAR
         X1=INT((80-MaxLen)/2-1)
         Y1=Line
         X2=X1+MaxLen+1
         Y2=Y1+NumItems+1

         @Y1,X1 ?? ""
         PAINTCANVAS FILL ""
           Y1,X1+1,Y1,X1+MaxLen
         @Y1,X2 ?? ""

         FOR i FROM 1 TO NumItems
           @Y1+i,X1 ?? ""+SPACES(MaxItemLen -
                       LEN(ItemAr[i]))+ItemAr[i] +
                       " - "+DescripAr[i]
           @Y1+i,X2 ?? ""
         ENDFOR

         @Y2,X1 ?? ""
         PAINTCANVAS FILL ""
           Y2,X1+1,Y2,X1+MaxLen
         @Y2,X2 ?? ""

         PAINTCANVAS
           ATTRIBUTE Color
           Y1,X1,Y2,X2

         STYLE
         CANVAS ON
  ENDIF

  SHOWARRAY
    ItemAr
    DescripAr
  TO Element
  RETURN Element
ENDPROC

WRITELIB "FullMenu" FullScreenMenu
